#!/bin/bash

move_file() {
    source_path=$1
    target_path=$2
    # 检查源文件或目录是否存在
    if [ ! -e "$source_path" ]; then
        echo "$source_path not exist, no move file."
        return
    fi
    # 确保目标路径以 / 结尾，如果不是目录则取其目录部分
    local last_char=$(echo "$target_path" | awk '{sub(/ *$/,""); print substr($0,length)}')
    if [ "$last_char" == "/" ]; then
        target_dir=$target_path
    else
        if [ -d "$target_path" ]; then
            target_dir=$target_path
        else
            target_dir=$(dirname "$target_path")
        fi
    fi
    echo "target_dir: $target_dir"
    
    # 检查目标目录是否存在，如果不存在则创建
    if [ ! -d "$target_dir" ]; then
        mkdir -p "$target_dir"
        echo "$target_dir not exist, have created the directory."
    fi
    
    # 执行mv操作
    mv $source_path $target_path
    echo $source_path move to $target_path
}

# 软件安装路径
BASE_DIR=/usr/share/loongnix-theme
# 备份原cartoon主题部分文件，以便恢复cartoon主题
# 恢复Login背景图片
move_file $BASE_DIR/cartoon_backup/cartoon-artwork/login-bg.png /usr/share/cartoon-artwork/

# 恢复默认用户头像配置文件
move_file $BASE_DIR/cartoon_backup/avatar/loongson /var/lib/AccountsService/users/

# 恢复用户头像
# 定义文件夹a和b的路径
folder_a="$BASE_DIR/backgrounds/faces"
folder_b="/usr/share/pixmaps/cartoon-faces"

# 遍历文件夹a中的所有文件
for file in "$folder_a"/*; do
    # 提取文件名
    filename=$(basename "$file")
    
    # 检查文件夹b中是否存在同名文件
    if [ -f "$folder_b/$filename" ]; then
        # 如果存在，则删除文件夹b中的同名文件
        rm "$folder_b/$filename"
        echo "已删除：$folder_b/$filename"
    fi
done
